"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DuckDBQuery = void 0;
const schema_compiler_1 = require("@cubejs-backend/schema-compiler");
const GRANULARITY_TO_INTERVAL = {
    day: date => `DATE_TRUNC('day', ${date})`,
    week: date => `DATE_TRUNC('week', ${date})`,
    hour: date => `DATE_TRUNC('hour', ${date})`,
    minute: date => `DATE_TRUNC('minute', ${date})`,
    second: date => `DATE_TRUNC('second', ${date})`,
    month: date => `DATE_TRUNC('month', ${date})`,
    quarter: date => `DATE_TRUNC('quarter', ${date})`,
    year: date => `DATE_TRUNC('year', ${date})`
};
class DuckDBFilter extends schema_compiler_1.BaseFilter {
}
class DuckDBQuery extends schema_compiler_1.BaseQuery {
    newFilter(filter) {
        return new DuckDBFilter(this, filter);
    }
    convertTz(field) {
        return `timezone('${this.timezone}', ${field}::timestamptz)`;
    }
    timeGroupedColumn(granularity, dimension) {
        return GRANULARITY_TO_INTERVAL[granularity](dimension);
    }
    countDistinctApprox(sql) {
        return `approx_count_distinct(${sql})`;
    }
    sqlTemplates() {
        const templates = super.sqlTemplates();
        templates.functions.DATETRUNC = 'DATE_TRUNC({{ args_concat }})';
        templates.functions.LEAST = 'LEAST({{ args_concat }})';
        templates.functions.GREATEST = 'GREATEST({{ args_concat }})';
        return templates;
    }
}
exports.DuckDBQuery = DuckDBQuery;
//# sourceMappingURL=DuckDBQuery.js.map